@@ -9,5 +9,15 @@ pkill -f ubuntu-sso-login
 python /usr/lib/ubuntu-sso-client/ubuntu-sso-login &
 
 # s-c
-export PYTHONPATH=$(pwd)
+if [ -n "$PYTHONPATH" ]; then
+    export PYTHONPATH=$(pwd):$PYTHONPATH
+else
+    export PYTHONPATH=$(pwd)
+fi
+
+
+if [ ! -d "./build" ]; then
+    echo "Please run: 'python setup.py build' before $0"
+fi
+
 ./software-center $@
